local EsoBR = {}
EsoBR.Flags = { "en", "br" }
EsoBR.Version = "1.0.0"
EsoBR.API = 101042
EsoBR.Name = "EsoBR"
EsoBR.DropdownParameters = {
	["br"] = "Somente Português",
	["bren"] = "Português+Inglês",
	["enbr"] = "Inglês+Português",
	["en"] = "Somente Inglês",
}
EsoBR.StringsBackup = {
	["SI_ABILITY_NAME_AND_RANK"] = GetString(SI_ABILITY_NAME_AND_RANK),
	["SI_ABILITY_TOOLTIP_NAME"] = GetString(SI_ABILITY_TOOLTIP_NAME),
	["SI_ITEM_FORMAT_STR_ENCHANT_HEADER_NAMED"] = GetString(SI_ITEM_FORMAT_STR_ENCHANT_HEADER_NAMED),
	["SI_ITEM_FORMAT_STR_ITEM_TRAIT_HEADER"] = GetString(SI_ITEM_FORMAT_STR_ITEM_TRAIT_HEADER),
	["SI_ITEM_FORMAT_STR_ITEM_TRAIT_WITH_ICON_HEADER"] = GetString(SI_ITEM_FORMAT_STR_ITEM_TRAIT_WITH_ICON_HEADER),
	["SI_ITEM_FORMAT_STR_SET_NAME"] = GetString(SI_ITEM_FORMAT_STR_SET_NAME),
	["SI_TOOLTIP_ITEM_NAME"] = GetString(SI_TOOLTIP_ITEM_NAME),
	["SI_ITEM_FORMAT_STR_SET_NAME_NO_COUNT"] = GetString(SI_ITEM_FORMAT_STR_SET_NAME_NO_COUNT),
}

EsoBR.Defaults = {
	Anchor = { BOTTOMRIGHT, BOTTOMRIGHT, 0, 7 },
	-- Misc
	ShowNPC = "bren",
	ShowLocations = "bren",
	ShowCraft = "bren",
	ShowMatColeta = "bren",
	ShowMateriais = "bren",
	ShowConjuntos = "bren",
	ShowBebiComi = "bren",
	-- Abilities
	ShowAbilitiesMenu = "br",
	ShowAbilitiesTooltip = "bren",
	-- Champion
	ShowChampionTooltip = "bren",
	-- Items
	ShowItemsNamesTooltip = "bren",
	ShowItemsEnchantsTooltip = "bren",
	ShowItemsTraitsTooltip = "bren",
	ShowItemsSetsTooltip = "bren",
	IsUpdateNeeded = true,
	-- Collections
	EnglishSearch = true,
	ShowCollectionsSetsMenu = "bren",
	--ShowTributeCards = "br",
	Data = {
		ApiVersion = 0,
		AddonVersion = "",
		Abilities = {},
		Items = {},
		Sets = {},
		SetsNames = {},
		Traits = {},
		Potions = {},
		Locations = {},
		Parts = {},
		Prefixes = {},
		Affixes = {},
		EnchantPrefixes = {},
		--TributeCards = {},
	}
}
EsoBR.DefaultsCharacter = {
	IsFirstLaunch = true
}
EsoBR.Settings = EsoBR.Defaults
EsoBR.SettingsCharacter = EsoBR.DefaultsCharacter

function EsoBR_Change(lang)
	if GetCVar("language.2") ~= lang then
		SetCVar("language.2", lang)
	else
		ZO_Alert(UI_ALERT_CATEGORY_ERROR, SOUNDS.NEGATIVE_CLICK, "Você já mudou para este idioma.")
	end
end

function EsoBR:RefreshUI()
	local flagControl
	local count = 0
	local flagTexture
	for _, flagCode in pairs(self.Flags) do
		flagTexture = "EsoBR/textures/"..flagCode..".dds"
		flagControl = GetControl("EsoBR_FlagControl_"..tostring(flagCode))
		if flagControl == nil then
			flagControl = CreateControlFromVirtual("EsoBR_FlagControl_", EsoBRUI, "EsoBR_FlagControl", tostring(flagCode))
			GetControl("EsoBR_FlagControl_"..flagCode.."Texture"):SetTexture(flagTexture)
			if self:GetLanguage() ~= flagCode then
				flagControl:SetAlpha(0.3)
				if flagControl:GetHandler("OnMouseDown") == nil then flagControl:SetHandler("OnMouseDown", function() EsoBR_Change(flagCode) end) end
			end
		end
		flagControl:ClearAnchors()
		flagControl:SetAnchor(LEFT, EsoBRUI, LEFT, 14 +count*34, 0)
		count = count + 1
	end
	EsoBRUI:SetDimensions(25 +count*34, 50)
	EsoBRUI:SetMouseEnabled(true)
end

function EsoBR:GetLanguage()
	local lang = GetCVar("language.2")
	
	if lang == "br" then return lang end
	return "en"
end

function EsoBR:StartupMessage()
	if self.Settings.IsUpdateNeeded and self:IsDBOld() then
		self:ShowMsgBox("Boas-vindas ao EsoBR", "\n\n\n|ac|t256:256:EsoBR/Textures/logo.dds|t\n\n\n\n\n|alFinalize as configurações atualizando o Banco de Dados. Seu jogo sempre será executado na linguagem escolhida.\n\nPara alterar o idioma, pressione a tecla ESC e use o painel com bandeiras no canto inferior direito. Você pode alterar o idioma atribuíndo teclas de atalho nas configurações de controle.\n\nPor padrão todas as opções estão em PT-BR, para mais ajustes:\nESC -> Opções -> Addons -> EsoBR.", 1)
	end
	
	if self:IsDBOld() and not self.Settings.IsUpdateNeeded then
		d("O Banco de Dados do EsoBR está desatualizado. Para atualizar siga as opções: ESC -> Opções -> Addons -> EsoBR")
	end
	
	self:Check()
	
	EVENT_MANAGER:UnregisterForEvent("EsoBR_StartupMessage", EVENT_PLAYER_ACTIVATED)
end

function EsoBR:MapNameStyle()		
	if self.Settings.ShowLocations == "bren" or self.Settings.ShowLocations == "enbr" then
		ZO_WorldMapCornerTitle:SetFont("ZoFontWinH3")
	else
		ZO_WorldMapCornerTitle:SetFont("ZoFontWinH1")
	end
	
	local scrollData = ZO_ScrollList_GetDataList(ZO_WorldMapLocationsList)
    ZO_ClearNumericallyIndexedTable(scrollData)
	WORLD_MAP_LOCATIONS_DATA:RefreshLocationList()
	WORLD_MAP_LOCATIONS:BuildLocationList()
end

function EsoBR:OnInit(eventCode, addOnName)	
	if zo_strlower(addOnName) ~= zo_strlower(self.Name) then return end
	EVENT_MANAGER:UnregisterForEvent("EsoBR_OnAddOnLoaded", EVENT_ADD_ON_LOADED)
	
	
	self.Settings = ZO_SavedVars:NewAccountWide("EsoBRVariables", 1, nil, self.Defaults)
	self.SettingsCharacter = ZO_SavedVars:New("EsoBRVariables", 1, nil, self.DefaultsCharacter)
	
	if self.SettingsCharacter.IsFirstLaunch == true then
		SetSetting(SETTING_TYPE_SUBTITLES, SUBTITLE_SETTING_ENABLED_FOR_NPCS, "true")
		SetSetting(SETTING_TYPE_SUBTITLES, SUBTITLE_SETTING_ENABLED_FOR_VIDEOS, "true")
		self.SettingsCharacter.IsFirstLaunch = false
	end
	
	for _, flagCode in pairs(self.Flags) do
		ZO_CreateStringId("SI_BINDING_NAME_"..string.upper(flagCode), string.upper(flagCode))
	end

	self:RefreshUI()
	
	EsoBRUI:ClearAnchors()
	EsoBRUI:SetAnchor(self.Settings.Anchor[1], GuiRoot, self.Settings.Anchor[2], self.Settings.Anchor[3], self.Settings.Anchor[4])
	
	self.LAM = ESOBR_SETTINGS:New(self)
	
	ZO_CreateStringId("SI_BINDING_NAME_ESOBR_EN", "Língua Inglesa")
	ZO_CreateStringId("SI_BINDING_NAME_ESOBR_BR", "Língua Portuguesa")
	
	if self:GetLanguage() == "br" then
		EsoBR_init()
	end
	
	function ZO_GameMenu_OnShow(control)
		if control.OnShow then
			control.OnShow(control.gameMenu)
			EsoBRUI:SetHidden(hidden)
		end
	end
	
	function ZO_GameMenu_OnHide(control)
		if control.OnHide then
			control.OnHide(control.gameMenu)
			EsoBRUI:SetHidden(not hidden)
		end
	end
end

function EsoBR:IsDBOld()
	local rsv = self.Settings.Data
	if not rsv.ApiVersion or not rsv.AddonVersion or (rsv.ApiVersion ~= GetAPIVersion()) or (rsv.AddonVersion ~= self.Version) then
		return true
	else
		return false
	end
end

function EsoBR:CloseMsgBox()
	ZO_Dialogs_ReleaseDialog("EsoBRDialog", false)
end

function EsoBR:ShowMsgBox(title, msg, typ)

	local callback = {}

	callback = {
		[1] = 
		{
			keybind = "DIALOG_PRIMARY",
			text = "Atualizar Banco",
			callback =
				function ()
					EsoBR_Dump()
				end,
            clickSound = SOUNDS.DIALOG_ACCEPT,
		},
		[2] =
		{
			keybind = "DIALOG_NEGATIVE",
            text = "Cancelar", 
			callback =
				function ()
					self.Settings.IsUpdateNeeded = false
				end,
            clickSound = SOUNDS.DIALOG_DECLINE,
		},
	}
	
	local confirmDialog = 
	{
		canQueue = true,
		onlyQueueOnce = true,
		gamepadInfo = { dialogType = GAMEPAD_DIALOGS.BASIC },
		title = { text = title },
		mainText = { text = msg },
		buttons = callback
	}
	
	ZO_Dialogs_RegisterCustomDialog("EsoBRDialog", confirmDialog)
	self:CloseMsgBox()
	
	--if IsInGamepadPreferredMode() then
	--	zo_callLater(function()
	--		ZO_Dialogs_ShowGamepadDialog("EsoBRDialog")
	--	end, 500)
	--else
		ZO_Dialogs_ShowDialog("EsoBRDialog")
	--end
end

function EsoBR_init()
	
	if not EsoBR:IsDBOld() then
		
		if EsoBR.Settings.ShowLocations ~= "br" and EsoBR_doubleNamesLocations then
			LFGDoubleNames(EsoBR)
			EsoBR_doubleNamesLocations(EsoBR)
		end
		
		if EsoBR.Settings.ShowNPC ~= "br" and EsoBR_doubleNamesNPC then
			EsoBR_doubleNamesNPC(EsoBR)
		end
		
		if EsoBR.Settings.ShowMatColeta ~= "br" and EsoBR_doubleNamesMatColeta then
			EsoBR_doubleNamesMatColeta(EsoBR)
		end
	
		if EsoBR.Settings.ShowMateriais ~= "br" and EsoBR_doubleNamesMateriais then
			EsoBR_doubleNamesMateriais(EsoBR)
		end
	
		if EsoBR.Settings.ShowConjuntos ~= "br" and EsoBR_doubleNamesConjuntos then
			EsoBR_doubleNamesConjuntos(EsoBR)
		end 
		
		if EsoBR.Settings.ShowBebiComi ~= "br" and EsoBR_doubleNamesBebidaseComidas then
			EsoBR_doubleNamesBebidaseComidas(EsoBR)
		end
		
		if EsoBR.Settings.ShowCraft ~= "br" and EsoBR_doubleNamesBoth then
			EsoBR_doubleNamesBoth(EsoBR)
		end
		
		if (EsoBR.Settings.ShowAbilitiesMenu ~= "br" or EsoBR.Settings.ShowAbilitiesTooltip ~= "br") and EsoBR_doubleNamesAbilities then
			EsoBR_doubleNamesAbilities(EsoBR)
		end
		
		if (EsoBR.Settings.ShowChampionMenu ~= "br" or EsoBR.Settings.ShowChampionTooltip ~= "br") and EsoBR_doubleNamesChampion then
			EsoBR_doubleNamesChampion(EsoBR)
		end
		
		if (EsoBR.Settings.ShowItemsNamesTooltip ~= "br" or EsoBR.Settings.ShowItemsEnchantsTooltip ~= "br" or EsoBR.Settings.ShowItemsTraitsTooltip ~= "br" or EsoBR.Settings.ShowItemsSetsTooltip ~= "br") and EsoBR_doubleNamesItems then
			EsoBR_doubleNamesItems(EsoBR)
		end
		
		if (EsoBR.Settings.EnglishSearch or EsoBR.Settings.ShowCollectionsSetsMenu ~= "br") and EsoBR_doubleNamesCollections then
			EsoBR_doubleNamesCollections(EsoBR)
			ITEM_SET_COLLECTIONS_DATA_MANAGER:SortTopLevelCategories()
			ITEM_SET_COLLECTIONS_DATA_MANAGER:FireCallbacks("CollectionsUpdated")
		end
	end
end

function EsoBR_SaveAnchor()
	local isValidAnchor, point, relativeTo, relativePoint, offsetX, offsetY = EsoBRUI:GetAnchor()
	if isValidAnchor then
		EsoBR.Settings.Anchor = { point, relativePoint, offsetX, offsetY }
	end
end

function EsoBR:MagicReplace(str, what, with)
    what = zo_strgsub(what, "[%(%)%.%+%-%*%?%[%]%^%$%%]", "%%%1")
    with = zo_strgsub(with, "[%%]", "%%%%")
    return zo_strgsub(str, what, with)
end

function EsoBR:DumpRu()
	local rsv = EsoBR.Settings.Data
	
	for i = 1, 300000 do

		local hasSet, setName = GetItemLinkSetInfo(string.format("|H1:item:%d:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0|h|h", i)) 
		
		if hasSet then
			rsv.SetsNames[ZO_CachedStrFormat("<<z:1>>", setName)] = i
		end
	end
	
	for i = 1, #esobrLinks do
		rsv.Potions[zo_strlower(GetItemLinkName(string.format("|H1:item:%s:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0|h|h", esobrLinks[i])))] = esobrLinks[i]
	end
	
	for i = 1, #esobrParts do
		rsv.Parts[ZO_CachedStrFormat("<<z:1>>", GetItemLinkName(string.format("|H1:item:%d:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0|h|h", esobrParts[i])))] = esobrParts[i]
	end
	
	for i = 1, #esobrEnchantPrefixes do
		rsv.EnchantPrefixes[EsoBR:MagicReplace(zo_strlower(GetItemLinkName(string.format("|H1:item:%s:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0|h|h", esobrEnchantPrefixes[i]))), " " .. GetItemLinkName("|H1:item:5364:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0|h|h"), "")] = esobrEnchantPrefixes[i]
	end
	
	for i = 1, #esobrPrefixes do
		local str = EsoBR:MagicReplace(ZO_CachedStrFormat("<<z:1>>", GetItemLinkName(string.format("|H1:item:%s:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0|h|h", esobrPrefixes[i]))), " " .. ZO_CachedStrFormat("<<z:1>>", GetItemLinkName("|H1:item:" .. string.match(esobrPrefixes[i], "^(%d+):") .. ":0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0|h|h")), "")
		rsv.Prefixes[str:sub(1, #str - 4)] = esobrPrefixes[i]
	end
	
	for i = 1, #esobrAffixes do
		rsv.Affixes[EsoBR:MagicReplace(ZO_CachedStrFormat("<<z:1>>", GetItemLinkName(string.format("|H1:item:43533:0:0:%d:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0|h|h", esobrAffixes[i]))), ZO_CachedStrFormat("<<z:1>>", GetItemLinkName("|H1:item:43533:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0|h|h")) .. " ", "")] = esobrAffixes[i]
	end
	
	-- Locations
	
	local backupLocations = EsoBR.Settings.ShowLocations
	EsoBR.Settings.ShowLocations = "br"
	
	local zonesCount = GetNumZones()
	for i = 1, zonesCount do
		local locationName = ZO_CachedStrFormat("<<z:1>>", GetZoneNameByIndex(i))
		if locationName then
			rsv.Locations[locationName] = string.format("zone:%d:0", i)
		end
		
		local POIsCount = GetNumPOIs(i)
		for j = 1, POIsCount do
			local locationName = ZO_CachedStrFormat("<<z:1>>", GetPOIInfo(i, j))
			if locationName then
				rsv.Locations[locationName] = string.format("poi:%d:%d", i, j)
			end
		end
	end
	
	local fastTravelNodesCount = GetNumFastTravelNodes()
	for i = 1, fastTravelNodesCount do
		local _, locationName = GetFastTravelNodeInfo(i)
		if locationName then
			rsv.Locations[ZO_CachedStrFormat("<<z:1>>", locationName)] = string.format("ft:%d:0", i)
		end
	end
	
	for i = 1, 1000 do
		local locationName = ZO_CachedStrFormat("<<z:1>>", GetKeepName(i))
		if locationName then
			rsv.Locations[locationName] = string.format("keep:%d:0", i)
		end
	end
	
	EsoBR.Settings.ShowLocations = backupLocations
	
	EsoBR.Settings["enDump"] = true
	SetCVar("language.2", "en")
end

function EsoBR:DumpEn()
	local rsv = EsoBR.Settings.Data
	
	-- Items
	
	for i = 1, 300000 do
		local itemName = GetItemLinkName(string.format("|H1:item:%d:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0|h|h", i))
		
		if itemName and itemName ~= "" and not string.match(itemName, "_") then
			rsv.Items[i] = ZO_CachedStrFormat(SI_TOOLTIP_ITEM_NAME, itemName)
		end

		local hasSet, setName, _, _, _, setId = GetItemLinkSetInfo(string.format("|H1:item:%d:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0|h|h", i))
		
		if hasSet then
			rsv.Sets[setId] = setName
		end

		--[[local _, enchantHeader = GetItemLinkEnchantInfo("|H1:item:" .. i .. ":0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0|h|h")
		local enchantId = GetItemLinkFinalEnchantId("|H1:item:" .. i .. ":0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0|h|h")

		if enchantHeader and enchantHeader ~= "" and enchantHeader ~= "Enchantment" then
			rsv.Enchants[enchantId] = EsoBR:MagicReplace(enchantHeader, " Enchantment", "")
		end]]
	end
	
	-- Tribute Cards
	
	--[[for i = 1, 1000 do
		local cardName = GetTributeCardName(i)
		
		if cardName and cardName ~= "" then
			rsv.TributeCards[i] = ZO_CachedStrFormat(SI_TOOLTIP_ITEM_NAME, cardName)
		end
	end]]
	
	-- Set Names
	
	for index,value in pairs(rsv.SetsNames) do
		local hasSet, setName = GetItemLinkSetInfo(string.format("|H1:item:%d:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0|h|h", value))
		rsv.SetsNames[index] = ZO_CachedStrFormat(SI_TOOLTIP_ITEM_NAME, setName)
	end
	
	-- Alchemy
	
	for index,value in pairs(rsv.Potions) do
		rsv.Potions[index] = ZO_CachedStrFormat(SI_TOOLTIP_ITEM_NAME, GetItemLinkName(string.format("|H1:item:%s:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0|h|h", value)))
	end
	
	-- Item Parts
	
	for index,value in pairs(rsv.Parts) do
		rsv.Parts[index] = ZO_CachedStrFormat(SI_TOOLTIP_ITEM_NAME, GetItemLinkName(string.format("|H1:item:%d:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0|h|h", value)))
	end
	
	-- Enchantment Prefixes
	
	for index,value in pairs(rsv.EnchantPrefixes) do
		rsv.EnchantPrefixes[index] = ZO_CachedStrFormat(SI_TOOLTIP_ITEM_NAME, EsoBR:MagicReplace(GetItemLinkName(string.format("|H1:item:%s:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0|h|h", value)), " " .. GetItemLinkName("|H1:item:5364:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0|h|h"), ""))
	end
	
	-- Item Prefixes
	
	for index,value in pairs(rsv.Prefixes) do
		rsv.Prefixes[index] = EsoBR:MagicReplace(ZO_CachedStrFormat(SI_TOOLTIP_ITEM_NAME, GetItemLinkName(string.format("|H1:item:%s:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0|h|h", value))), " " .. ZO_CachedStrFormat(SI_TOOLTIP_ITEM_NAME, GetItemLinkName("|H1:item:" .. string.match(value, "^(%d+):") .. ":0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0|h|h")), "")
	end
	
	-- Item Affixes
	
	for index,value in pairs(rsv.Affixes) do
		rsv.Affixes[index] = EsoBR:MagicReplace(ZO_CachedStrFormat(SI_TOOLTIP_ITEM_NAME, GetItemLinkName(string.format("|H1:item:43533:0:0:%d:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0|h|h", value))), ZO_CachedStrFormat(SI_TOOLTIP_ITEM_NAME, GetItemLinkName("|H1:item:43533:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0|h|h")) .. " ", "")
	end
	
	-- Locations
	
	for index,value in pairs(rsv.Locations) do
		local locType, locId, locSubId = string.match(value, "^(.*):(%d+):(%d+)$")
		
		if locType and locId and locSubId then
			if locType == "zone" then
				rsv.Locations[index] = ZO_CachedStrFormat(SI_ZONE_NAME, GetZoneNameByIndex(locId))
			elseif locType == "poi" then
				rsv.Locations[index] = ZO_CachedStrFormat(SI_ZONE_NAME, GetPOIInfo(locId, locSubId))
			elseif locType == "keep" then
				rsv.Locations[index] = ZO_CachedStrFormat(SI_ZONE_NAME, GetKeepName(locId))
			elseif locType == "ft" then
				local _, locationName = GetFastTravelNodeInfo(locId)
				rsv.Locations[index] = ZO_CachedStrFormat(SI_ZONE_NAME, locationName)
			end
		end
	end
	
	-- Traits
	
	for i = 1, 100 do
		local traitName = GetString("SI_ITEMTRAITTYPE", i)
		
		if traitName and traitName ~= "" then
			rsv.Traits[i] = traitName
		end
	end
	
	-- Abilities
	
	local numSkillTypes = GetNumSkillTypes()
	
	for i = 1, numSkillTypes do
		local numSkillLines = GetNumSkillLines(i)
		
		for j = 1, numSkillLines do
			local numSkillAbilities = GetNumSkillAbilities(i, j)
			
			for k = 1, numSkillAbilities do
				
				local _, _, _, passive = GetSkillAbilityInfo(i, j, k)
				
				if passive then
					for l = 1,GetNumPassiveSkillRanks(i, j, k) do
						local currentMorphId = GetSpecificSkillAbilityInfo(i, j, k, 0, l)
						rsv.Abilities[currentMorphId] = GetAbilityName(currentMorphId)
					end
				else
					local currentMorphId = GetSpecificSkillAbilityInfo(i, j, k, 0, 1)
					rsv.Abilities[currentMorphId] = GetAbilityName(currentMorphId)
					
					local currentMorphId = GetSpecificSkillAbilityInfo(i, j, k, 1, 1)
					rsv.Abilities[currentMorphId] = GetAbilityName(currentMorphId)
					
					local currentMorphId = GetSpecificSkillAbilityInfo(i, j, k, 2, 1)
					rsv.Abilities[currentMorphId] = GetAbilityName(currentMorphId)
				end
			end
		end
	end
	
	for key,value in pairs(esobrCompanionAbilities) do
		rsv.Abilities[key] = GetAbilityName(key)
	end

	for i = 1, GetNumChampionDisciplines() do
		for j = 1, GetNumChampionDisciplineSkills(i) do
			rsv.Abilities[GetChampionAbilityId(GetChampionSkillId(i, j))] = GetChampionSkillName(GetChampionSkillId(i, j))
		end
	end
	
	EsoBR.Settings["enDump"] = nil
	EsoBR.Settings["success"] = true
	
	rsv.ApiVersion = GetAPIVersion()
	rsv.AddonVersion = EsoBR.Version
	EsoBR.Settings.IsUpdateNeeded = true,
	
	SetCVar("language.2", "br")
end

function EsoBR:Check()

	local rsv = EsoBR.Settings

	if GetCVar("language.2") == "en" and rsv["enDump"] ~= nil then
		EsoBR:DumpEn()
	end
	
	if GetCVar("language.2") == "br" and rsv["brDump"] ~= nil then
		rsv["brDump"] = nil
		EsoBR:DumpRu()
	end
	
	if rsv["success"] ~= nil then
		rsv["success"] = nil
	end
end

function EsoBR:IsAddonRunning(addonName)
    local manager = GetAddOnManager()
    for i = 1, manager:GetNumAddOns() do
        local name, _, _, _, _, state = manager:GetAddOnInfo(i)
        if name == addonName and state == ADDON_STATE_ENABLED then
            return true
        end
    end
    return false
end

function EsoBR_Dump()
	local rsd = EsoBR.Settings.Data
	rsd.Sets = {}
	rsd.SetsNames = {}
	rsd.Potions = {}
	rsd.Traits = {}
	rsd.Abilities = {}
	rsd.Items = {}
	rsd.Parts = {}
	rsd.Prefixes = {}
	rsd.Affixes = {}
	rsd.EnchantPrefixes = {}
	rsd.Locations = EsoBR_getLocations()
	
	if GetCVar("language.2") == "br" then
		EsoBR:DumpRu()
	else
		EsoBR.Settings["brDump"] = true
		SetCVar("language.2", "br")
	end
end

EVENT_MANAGER:RegisterForEvent("EsoBR_OnAddOnLoaded", EVENT_ADD_ON_LOADED, function(_event, _name) EsoBR:OnInit(_event, _name) end)
EVENT_MANAGER:RegisterForEvent("EsoBR_StartupMessage", EVENT_PLAYER_ACTIVATED, function(...) EsoBR:StartupMessage() end)
