local EsoBRSettings = ZO_Object:Subclass()
ESOBR_SETTINGS = EsoBRSettings

function EsoBRSettings:New(...)
    local settings = ZO_Object.New(self)
    settings:Initialize(...)
    return settings
end

function EsoBRSettings:Initialize(EsoBR)
	self.LAM = LibAddonMenu2
	self:InitSettings(EsoBR)
end

function EsoBRSettings:InitSettings(EsoBR)

    local panelData = {
		type = "panel",
		name = EsoBR.Name,
		displayName = "Tradução Brasileira não-oficial do ESO.",
		author = "Mestre Frooke",
		version = EsoBR.Version,
		slashCommand = "/esobr",
		registerForRefresh = true,
		registerForDefaults = true,
		feedback = "https://www.esoui.com/downloads/info2256-EsoBR-TraduoPortugus.html",
		website = "http:/www.universoeso.com.br"
	}
	
	self.LAM:RegisterAddonPanel(panelData.name, panelData)
	
	local optionsTable = {}
	
	table.insert(optionsTable, {
		type = "header",
		name = "Atualização do banco de dados de títulos.",
		width = "full",	--or "half" (optional)
	})
	
	table.insert(optionsTable, {
		type = "button",
		name = "Atualizar",
		tooltip = "Permite atualizar o banco de dados de nomes.",
		func = EsoBR_Dump,
	})

	table.insert(optionsTable, {
		type = "header",
		name = "Nomes duplos em Tamriel",
		tooltip = "Essa opção permite personalizar alguns nomes duplos em Tamriel.",
		width = "full",	--or "half" (optional)
	})
	
	table.insert(optionsTable, {
		type = "dropdown",
		name = "Nomes de Personagens:",
		warning = (function()
			if EsoBR:IsDBOld() then
				return "Necessária atualização do banco de dados."
			else
				return false
			end
		end),
		disabled = function() return EsoBR:IsDBOld() end,
		tooltip = "Essa opção permite personalizar a exibição de nomes duplos nos personagens.",
		choices = {EsoBR.DropdownParameters["br"], EsoBR.DropdownParameters["bren"], EsoBR.DropdownParameters["enbr"], EsoBR.DropdownParameters["en"]},
		choicesValues = {"br", "bren", "enbr", "en"},
		getFunc = function() return EsoBR.Settings.ShowNPC end,
		setFunc = (function(value)
			EsoBR.Settings.ShowNPC = value
			
			if value ~= "br" and EsoBR_doubleNamesNPC then
				EsoBR_doubleNamesNPC(EsoBR)
			end
		end),
		width = "full",
	})
	
	table.insert(optionsTable, {
		type = "dropdown",
		name = "Nomes de Lugares:",
		warning = (function()
			if EsoBR:IsDBOld() then
				return "Necessária atualização do banco de dados."
			else
				return false
			end
		end),
		disabled = function() return EsoBR:IsDBOld() end,
		tooltip = "Essa opção permite personalizar a exibição de nomes duplso dos lugares.",
		choices = {EsoBR.DropdownParameters["br"], EsoBR.DropdownParameters["bren"], EsoBR.DropdownParameters["enbr"], EsoBR.DropdownParameters["en"]},
		choicesValues = {"br", "bren", "enbr", "en"},			
		getFunc = function() return EsoBR.Settings.ShowLocations end,
		setFunc = (function(value)
			EsoBR.Settings.ShowLocations = value
			
			if value ~= "br" and EsoBR_doubleNamesLocations then
				EsoBR_doubleNamesLocations(EsoBR)
			end
			
			FRIENDS_LIST_MANAGER:BuildMasterList()
			FRIENDS_LIST_MANAGER:OnSocialDataLoaded()
			GUILD_ROSTER_MANAGER:BuildMasterList()
			GUILD_ROSTER_MANAGER:OnGuildDataLoaded()
			
			LFGDoubleNames(EsoBR)
			
			CADWELLS_ALMANAC:RefreshList()
			CALLBACK_MANAGER:FireCallbacks("OnWorldMapChanged")
			EsoBR:MapNameStyle()
		end),
		width = "full",
	})
	
	table.insert(optionsTable, {
		type = "dropdown",
		name = "Nomes de Estação de Profissão:",
		warning = (function()
			if EsoBR:IsDBOld() then
				return "Necessária atualização do banco de dados."
			else
				return false
			end
		end),
		disabled = function() return EsoBR:IsDBOld() end,
		tooltip = "Essa opção permite personalizar a exibição de nomes duplos na Estação de Profissão.",
		choices = {EsoBR.DropdownParameters["br"], EsoBR.DropdownParameters["bren"], EsoBR.DropdownParameters["enbr"], EsoBR.DropdownParameters["en"]},
		choicesValues = {"br", "bren", "enbr", "en"},
		getFunc = function() return EsoBR.Settings.ShowCraft end,
		setFunc = (function(value)
			EsoBR.Settings.ShowCraft = value
			
			if value ~= "br" and EsoBR_doubleNamesBoth then
				EsoBR_doubleNamesBoth(EsoBR)
			end
		end),
		width = "full",
	})
	
	table.insert(optionsTable, {
		type = "dropdown",
		name = "Nomes de Itens Coletáveis:",
		warning = (function()
			if EsoBR:IsDBOld() then
				return "Necessária atualização do banco de dados."
			else
				return false
			end
		end),
		disabled = function() return EsoBR:IsDBOld() end,
		tooltip = "Essa opção permite personalizar a exibição de nomes duplos dos objetos de coleta.",
		choices = {EsoBR.DropdownParameters["br"], EsoBR.DropdownParameters["bren"], EsoBR.DropdownParameters["enbr"], EsoBR.DropdownParameters["en"]},
		choicesValues = {"br", "bren", "enbr", "en"},
		getFunc = function() return EsoBR.Settings.ShowMatColeta end,
		setFunc = (function(value)
			EsoBR.Settings.ShowMatColeta = value
			
			if value ~= "br" and EsoBR_doubleNamesMatColeta then
				EsoBR_doubleNamesMatColeta(EsoBR)
			end
		end),
		width = "full",
	})
	
	table.insert(optionsTable, {
		type = "header",
		name = "Conjuntos, Materiais de Profissão e Provisionamento",
		tooltip = "Essa opção permite personalizar os nomes duplos de alguns itens na sua mochila",
		width = "full",	--or "half" (optional)
	})
	
	table.insert(optionsTable, {
		type = "dropdown",
		name = "Nomes duplos Materiais de Profissão:",
		warning = (function()
			if EsoBR:IsDBOld() then
				return "Necessária atualização do banco de dados."
			else
				return false
			end
		end),
		disabled = function() return EsoBR:IsDBOld() end,
		tooltip = "Essa opção permite personalizar a exibição de nomes duplos de materiais na mochila.",
		choices = {EsoBR.DropdownParameters["br"], EsoBR.DropdownParameters["bren"], EsoBR.DropdownParameters["enbr"], EsoBR.DropdownParameters["en"]},
		choicesValues = {"br", "bren", "enbr", "en"},
		getFunc = function() return EsoBR.Settings.ShowMateriais end,
		setFunc = (function(value)
			EsoBR.Settings.ShowMateriais = value
			
			if value ~= "br" and EsoBR_doubleNamesMateriais then
				EsoBR_doubleNamesMateriais(EsoBR)
			end
		end),
		width = "full",
	})
	
	table.insert(optionsTable, {
		type = "dropdown",
		name = "Nomes duplos Conjuntos:",
		warning = (function()
			if EsoBR:IsDBOld() then
				return "Necessária atualização do banco de dados."
			else
				return false
			end
		end),
		disabled = function() return EsoBR:IsDBOld() end,
		tooltip = "Essa opção permite personalizar a exibição de nomes duplos de conjuntos de armas e armaduras na mochila.",
		choices = {EsoBR.DropdownParameters["br"], EsoBR.DropdownParameters["bren"], EsoBR.DropdownParameters["enbr"], EsoBR.DropdownParameters["en"]},
		choicesValues = {"br", "bren", "enbr", "en"},
		getFunc = function() return EsoBR.Settings.ShowConjuntos end,
		setFunc = (function(value)
			EsoBR.Settings.ShowConjuntos = value
			
			if value ~= "br" and EsoBR_doubleNamesConjuntos then
				EsoBR_doubleNamesConjuntos(EsoBR)
			end
		end),
		width = "full",
	})
	
	table.insert(optionsTable, {
		type = "dropdown",
		name = "Nomes duplos Provisionamento:",
		warning = (function()
			if EsoBR:IsDBOld() then
				return "Necessária atualização do banco de dados."
			else
				return false
			end
		end),
		disabled = function() return EsoBR:IsDBOld() end,
		tooltip = "Essa opção permite personalizar a exibição dos nomes duplos de bebidas, comidas e poções na mochila.",
		choices = {EsoBR.DropdownParameters["br"], EsoBR.DropdownParameters["bren"], EsoBR.DropdownParameters["enbr"], EsoBR.DropdownParameters["en"]},
		choicesValues = {"br", "bren", "enbr", "en"},
		getFunc = function() return EsoBR.Settings.ShowBebiComi end,
		setFunc = (function(value)
			EsoBR.Settings.ShowBebiComi = value
			
			if value ~= "br" and EsoBR_doubleNamesBebidaseComidas then
				EsoBR_doubleNamesBebidaseComidas(EsoBR)
			end
		end),
		width = "full",
	})
	
	
	table.insert(optionsTable, {
		type = "header",
		name = "Detalhes de Itens:",
		tooltip = "Permite definir como será mostrado o nome duplo nos detalhes do itens.",
		width = "full",	--or "half" (optional)
	})
	
	table.insert(optionsTable, {
		type = "dropdown",
		name = "Detalhes: Itens:",
		warning = (function()
			if EsoBR:IsDBOld() then
				return "Necessária atualização do banco de dados."
			else
				return false
			end
		end),
		disabled = function() return EsoBR:IsDBOld() end,
		choices = {EsoBR.DropdownParameters["br"], EsoBR.DropdownParameters["bren"], EsoBR.DropdownParameters["enbr"], EsoBR.DropdownParameters["en"]},
		choicesValues = {"br", "bren", "enbr", "en"},
		tooltip = "Permite definir o idioma para exibir os nomes duplos nos DETEALHES dos itens.",
		getFunc = function() return EsoBR.Settings.ShowItemsNamesTooltip end,
		setFunc = (function(value)
			EsoBR.Settings.ShowItemsNamesTooltip = value
			
			if value ~= "br" and EsoBR_doubleNamesItems then
				EsoBR_doubleNamesItems(EsoBR)
			end
		end),
	})
	
	table.insert(optionsTable, {
		type = "dropdown",
		name = "Detalhes: Encantamentos:",
		warning = (function()
			if EsoBR:IsDBOld() then
				return "Necessária atualização do banco de dados."
			else
				return false
			end
		end),
		disabled = function() return EsoBR:IsDBOld() end,
		choices = {EsoBR.DropdownParameters["br"], EsoBR.DropdownParameters["bren"], EsoBR.DropdownParameters["enbr"], EsoBR.DropdownParameters["en"]},
		choicesValues = {"br", "bren", "enbr", "en"},
		tooltip = "Permite definir o idioma para exibir os nomes duplos nos DETEALHES dos Encantamentos.",
		getFunc = function() return EsoBR.Settings.ShowItemsEnchantsTooltip end,
		setFunc = (function(value)
			EsoBR.Settings.ShowItemsEnchantsTooltip = value
			
			if value ~= "br" and EsoBR_doubleNamesItems then
				EsoBR_doubleNamesItems(EsoBR)
			end
		end),
	})
	
	table.insert(optionsTable, {
		type = "dropdown",
		name = "Detalhes: Materiais de Profissão",
		warning = (function()
			if EsoBR:IsDBOld() then
				return "Necessária atualização do banco de dados."
			else
				return false
			end
		end),
		disabled = function() return EsoBR:IsDBOld() end,
		choices = {EsoBR.DropdownParameters["br"], EsoBR.DropdownParameters["bren"], EsoBR.DropdownParameters["enbr"], EsoBR.DropdownParameters["en"]},
		choicesValues = {"br", "bren", "enbr", "en"},
		tooltip = "Permite definir o idioma para exibir os nomes duplos nos DETEALHES dos materiais de profissão.",
		getFunc = function() return EsoBR.Settings.ShowItemsTraitsTooltip end,
		setFunc = (function(value)
			EsoBR.Settings.ShowItemsTraitsTooltip = value
			
			if value ~= "br" and EsoBR_doubleNamesItems then
				EsoBR_doubleNamesItems(EsoBR)
			end
		end),
	})
	
	table.insert(optionsTable, {
		type = "dropdown",
		name = "Detalhes: Conjuntos:",
		warning = (function()
			if EsoBR:IsDBOld() then
				return "Necessária atualização do banco de dados."
			else
				return false
			end
		end),
		disabled = function() return EsoBR:IsDBOld() end,
		choices = {EsoBR.DropdownParameters["br"], EsoBR.DropdownParameters["bren"], EsoBR.DropdownParameters["enbr"], EsoBR.DropdownParameters["en"]},
		choicesValues = {"br", "bren", "enbr", "en"},
		tooltip = "Permite definir o idioma para exibir os nomes duplos nos DETEALHES dos Conjuntos.",
		getFunc = function() return EsoBR.Settings.ShowItemsSetsTooltip end,
		setFunc = (function(value)
			EsoBR.Settings.ShowItemsSetsTooltip = value
			
			if value ~= "br" and EsoBR_doubleNamesItems then
				EsoBR_doubleNamesItems(EsoBR)
			end
		end),
	})
		
	table.insert(optionsTable, {
		type = "header",
		name = "Habilidades e Pontos de Campeão",
		tooltip = "Essa opção permite personalizar o nome duplos das Habilidades e Pontos de Campeão.",
		width = "full",	--or "half" (optional)
	})
	
	table.insert(optionsTable, {
		type = "dropdown",
		name = "Menu: Habilidades:",
		warning = (function()
			if EsoBR:IsDBOld() then
				return "Necessária atualização do banco de dados."
			else
				return false
			end
		end),
		disabled = function() return EsoBR:IsDBOld() end,
		choices = {EsoBR.DropdownParameters["br"], EsoBR.DropdownParameters["en"]},
		choicesValues = {"br", "en"},
		tooltip = "Essa opção permite personalizar o nome das Habilidades no MENU .",
		getFunc = function() return EsoBR.Settings.ShowAbilitiesMenu end,
		setFunc = (function(value)
			EsoBR.Settings.ShowAbilitiesMenu = value
			
			if value ~= "br" and EsoBR_doubleNamesAbilities then
				EsoBR_doubleNamesAbilities(EsoBR)
			end
			
			SKILLS_WINDOW:RebuildSkillLineList()
			COMPANION_SKILLS_DATA_MANAGER:RebuildSkillsData()
		end),
	})
	
	table.insert(optionsTable, {
		type = "dropdown",
		name = "Detalhes: Habilidades:",
		warning = (function()
			if EsoBR:IsDBOld() then
				return "Necessária atualização do banco de dados."
			else
				return false
			end
		end),
		disabled = function() return EsoBR:IsDBOld() end,
		choices = {EsoBR.DropdownParameters["br"], EsoBR.DropdownParameters["bren"], EsoBR.DropdownParameters["enbr"], EsoBR.DropdownParameters["en"]},
		choicesValues = {"br", "bren", "enbr", "en"},
		tooltip = "Essa opção permite personalizar os nomes duplos no DETALHES das Habilidades",
		getFunc = function() return EsoBR.Settings.ShowAbilitiesTooltip end,
		setFunc = (function(value)
			EsoBR.Settings.ShowAbilitiesTooltip = value
			
			if value ~= "br" and EsoBR_doubleNamesAbilities then
				EsoBR_doubleNamesAbilities(EsoBR)
			end
		end),
	})
	
	table.insert(optionsTable, {
		type = "dropdown",
		name = "Detalhes: Pontos de Campeão:",
		warning = (function()
			if EsoBR:IsDBOld() then
				return "Necessária atualização do banco de dados."
			else
				return false
			end
		end),
		disabled = function() return EsoBR:IsDBOld() end,
		choices = {EsoBR.DropdownParameters["br"], EsoBR.DropdownParameters["bren"], EsoBR.DropdownParameters["enbr"], EsoBR.DropdownParameters["en"]},
		choicesValues = {"br", "bren", "enbr", "en"},
		tooltip = "Essa opção permite personalizar os nomes duplos nos DETALHES dos Pontos de Campeão",
		getFunc = function() return EsoBR.Settings.ShowChampionTooltip end,
		setFunc = (function(value)
			EsoBR.Settings.ShowChampionTooltip = value
			
			if value ~= "br" and EsoBR_doubleNamesChampion then
				EsoBR_doubleNamesChampion(EsoBR)
			end
		end),
	})
		
	table.insert(optionsTable, {
		type = "header",
		name = "Coleção de Conjuntos:",
		tooltip = "Permite que você Pesquise por nomes de conjuntos em inglês e português SOMENTE da Coleção de Conjutos.",
		width = "full",	--or "half" (optional)
	})	
	
	table.insert(optionsTable, {
		type = "checkbox",
		name = "Pesquisa bilíngue",
		warning = (function()
			if EsoBR:IsDBOld() then
				return "Necessária atualização do banco de dados."
			else
				return false
			end
		end),
		disabled = function() return EsoBR:IsDBOld() end,
		tooltip = "Permite que você use nomes de conjuntos em inglês ao pesquisar na Coleção de Conjuntos.",
		getFunc = function() return EsoBR.Settings.EnglishSearch end,
		setFunc = (function(value)
			EsoBR.Settings.EnglishSearch = value
			
			if value and EsoBR_doubleNamesCollections then
				EsoBR_doubleNamesCollections(EsoBR)
			end
		end),
	})
	
	table.insert(optionsTable, {
		type = "dropdown",
		name = "Menu: Coleção de Conjuntos:",
		warning = (function()
			if EsoBR:IsDBOld() then
				return "Necessária atualização do banco de dados."
			else
				return false
			end
		end),
		disabled = function() return EsoBR:IsDBOld() end,
		choices = {EsoBR.DropdownParameters["br"], EsoBR.DropdownParameters["bren"], EsoBR.DropdownParameters["enbr"], EsoBR.DropdownParameters["en"]},
		choicesValues = {"br", "bren", "enbr", "en"},
		tooltip = "Permite definir o idioma para exibição dos nomes dos conjuntos no menu de coleções.",
		getFunc = function() return EsoBR.Settings.ShowCollectionsSetsMenu end,
		setFunc = (function(value)
			EsoBR.Settings.ShowCollectionsSetsMenu = value
			
			if value ~= "br" and EsoBR_doubleNamesCollections then
				EsoBR_doubleNamesCollections(EsoBR)
			end
			ITEM_SET_COLLECTIONS_DATA_MANAGER:SortTopLevelCategories()
			ITEM_SET_COLLECTIONS_DATA_MANAGER:FireCallbacks("CollectionsUpdated")
		end),
	})
	
	table.insert(optionsTable, {
		type = "header",
		width = "full",	--or "half" (optional)
	})
	
	table.insert(optionsTable, {
			type = "checkbox",
			name = "Manter linguagem na próxima inicialização",
			tooltip = "Quando essa opção estiver ativada, o jogo será iniciado no idioma selecionado durante o jogo anterior.",
			getFunc = function()
				if GetCVar("IgnorePatcherLanguageSetting") == "1" then
					return true
				else
					return false
				end
			return GetCVar("IgnorePatcherLanguageSetting") end,
			setFunc = function(value)
				if value == true then
					SetCVar("IgnorePatcherLanguageSetting", "1")
				else
					SetCVar("IgnorePatcherLanguageSetting", "0")
				end
			end,			
	})
	table.insert(optionsTable, {
		type = "button",
		name = "Recarregar IU",
		width = "full",
		tooltip = "Recarregue a interface do usuário para confirmar as alterações feitas.",
		func = function() ReloadUI() end,
	})		
		
	self.LAM:RegisterOptionControls(panelData.name, optionsTable)
end